@@ -1075,7 +1075,7 @@ void EwsResource::messageSendRequestFinished(KJob *job)
 
 void EwsResource::foldersModifiedEvent(const EwsId::List &folders)
 {
-    Q_FOREACH (const EwsId &id, folders) {
+    for (const EwsId &id : folders) {
         Collection c;
         c.setRemoteId(id.id());
         CollectionFetchJob *job = new CollectionFetchJob(c, CollectionFetchJob::Base);
@@ -1129,7 +1129,7 @@ void EwsResource::fetchSpecialFolders()
 {
     CollectionFetchJob *job = new CollectionFetchJob(mRootCollection, CollectionFetchJob::Recursive, this);
     connect(job, &CollectionFetchJob::collectionsReceived, this, &EwsResource::specialFoldersCollectionsRetrieved);
-    connect(job, &CollectionFetchJob::result, this, [this](KJob *job) {
+    connect(job, &CollectionFetchJob::result, this, [](KJob *job) {
         if (job->error()) {
             qCWarningNC(EWSRES_LOG) << "Special folders fetch failed:" << job->errorString();
         }
@@ -1142,7 +1142,7 @@ void EwsResource::specialFoldersCollectionsRetrieved(const Collection::List &fol
     EwsId::List queryItems;
 
     queryItems.reserve(specialFolderList.count());
-    Q_FOREACH (const SpecialFolders &sf, specialFolderList) {
+    for (const SpecialFolders &sf : qAsConst(specialFolderList)) {
         queryItems.append(EwsId(sf.did));
     }
 
