@@ -35,7 +35,7 @@ class BatchFetcher : public KJob
     Q_OBJECT
 public:
     BatchFetcher(MessageHelper::Ptr messageHelper, const KIMAP::ImapSet &set, const KIMAP::FetchJob::FetchScope &scope, int batchSize, KIMAP::Session *session);
-    virtual ~BatchFetcher();
+    ~BatchFetcher() override;
     void start() override;
     void fetchNextBatch();
     void setUidBased(bool);
